@@ -1,7 +1,7 @@
 import os
 import subprocess
 import sys
-from typing import List
+from typing import List, Dict
 
 from termcolor_util import yellow, red
 
@@ -10,12 +10,16 @@ from git_monorepo.project_config import (
     get_current_commit,
     write_synchronized_commits,
     is_synchronized_commits_file_existing,
+    _resolve_in_repo,
 )
 
 
 def pull(sync: bool, folders: List[str]) -> None:
     monorepo = read_config()
 
+    # we normalize relative paths, extra slashes, etc
+    folders = [_resolve_in_repo(monorepo, it) for it in folders]
+
     pull_folders = set(folders)
     pull_folders.difference_update(monorepo.repos)
 
@@ -53,6 +57,12 @@ def pull(sync: bool, folders: List[str]) -> None:
                     monorepo.current_branch,
                 ],
                 cwd=monorepo.project_folder,
+                env=env_extend(
+                    {
+                        "EDITOR": "git-monorepo-editor",
+                        "GIT_MONOREPO_EDITOR_MESSAGE": f"git-monorepo: Sync {folder_name}",
+                    }
+                ),
             )
 
             continue
@@ -68,6 +78,12 @@ def pull(sync: bool, folders: List[str]) -> None:
                 monorepo.current_branch,
             ],
             cwd=monorepo.project_folder,
+            env=env_extend(
+                {
+                    "EDITOR": "git-monorepo-editor",
+                    "GIT_MONOREPO_EDITOR_MESSAGE": f"git-monorepo: Sync {folder_name}",
+                }
+            ),
         )
 
     current_commit = get_current_commit(project_folder=monorepo.project_folder)
@@ -82,3 +98,10 @@ def pull(sync: bool, folders: List[str]) -> None:
         return
 
     write_synchronized_commits(monorepo)
+
+
+def env_extend(extra_env: Dict[str, str]) -> Dict[str, str]:
+    result = dict(os.environ)
+    result.update(extra_env)
+
+    return result
