@@ -8,6 +8,7 @@ from git_monorepo.project_config import (
     write_synchronized_commits,
     is_synchronized_commits_file_existing,
 )
+from git_monorepo.pull_command import env_extend
 
 
 def push():
@@ -43,6 +44,12 @@ def push():
                 monorepo.current_branch,
             ],
             cwd=monorepo.project_folder,
+            env=env_extend(
+                {
+                    "EDITOR": "git-monorepo-editor",
+                    "GIT_MONOREPO_EDITOR_MESSAGE": f"git-monorepo: Sync {folder_name}",
+                }
+            ),
         )
 
     if not something_changed and is_synchronized_commits_file_existing(monorepo):
